Relevant links
==============

* COMPAS Links

  * `COMPAS <https://compas.dev/compas>`_
  * `COMPAS FAB <https://gramaziokohler.github.io/compas_fab>`_

|

* COMPAS RRC Organizations

  * `GitHub Organization <https://github.com/compas-rrc/>`_
  * `Docker Hub Organization <https://hub.docker.com/r/compasrrc/>`_

|

* Vendors

  * `ABB Robotics <https://new.abb.com/products/robotics>`_


Built at `NCCR DFAB <https://www.dfab.ch/>`_, Zurich 🤖
